Class: Events::EvictionCompleted
- Inherits:
-
Object
- Object
- Events::EvictionCompleted
- Defined in:
- lib/events/eviction_completed.rb
Overview
Emitted after Mneme advances the boundary past an eviction zone. Subscribers broadcast the cutoff to connected clients so they can drop messages below it.
Constant Summary collapse
- TYPE =
"eviction.completed"
Instance Attribute Summary collapse
-
#evict_above_id ⇒ Object
readonly
Returns the value of attribute evict_above_id.
-
#session_id ⇒ Object
readonly
Returns the value of attribute session_id.
Instance Method Summary collapse
- #event_name ⇒ Object
-
#initialize(session_id:, evict_above_id:) ⇒ EvictionCompleted
constructor
A new instance of EvictionCompleted.
- #to_h ⇒ Object
Constructor Details
#initialize(session_id:, evict_above_id:) ⇒ EvictionCompleted
Returns a new instance of EvictionCompleted.
15 16 17 18 |
# File 'lib/events/eviction_completed.rb', line 15 def initialize(session_id:, evict_above_id:) @session_id = session_id @evict_above_id = evict_above_id end |
Instance Attribute Details
#evict_above_id ⇒ Object (readonly)
Returns the value of attribute evict_above_id.
10 11 12 |
# File 'lib/events/eviction_completed.rb', line 10 def evict_above_id @evict_above_id end |
#session_id ⇒ Object (readonly)
Returns the value of attribute session_id.
10 11 12 |
# File 'lib/events/eviction_completed.rb', line 10 def session_id @session_id end |