Module: Melete::Tools::GoalMessaging

Included in:
FinishGoal, SetGoal, UpdateGoal
Defined in:
lib/melete/tools/goal_messaging.rb

Overview

Shared helper for goal tools that enqueue phantom pair messages when Melete creates, updates, or completes a goal.

Including classes must set @main_session to the owning Session.