Class: Events::MessageUpdated
- Inherits:
-
Object
- Object
- Events::MessageUpdated
- Defined in:
- lib/events/message_updated.rb
Overview
Emitted after a Message record is updated and committed. Used by subscribers that need to react to message changes (e.g. broadcasting updated token counts to WebSocket clients).
Constant Summary collapse
- TYPE =
"message.updated"
Instance Attribute Summary collapse
-
#message ⇒ Object
readonly
Returns the value of attribute message.
Instance Method Summary collapse
- #event_name ⇒ Object
-
#initialize(message) ⇒ MessageUpdated
constructor
A new instance of MessageUpdated.
- #to_h ⇒ Object
Constructor Details
#initialize(message) ⇒ MessageUpdated
Returns a new instance of MessageUpdated.
13 14 15 |
# File 'lib/events/message_updated.rb', line 13 def initialize() @message = end |
Instance Attribute Details
#message ⇒ Object (readonly)
Returns the value of attribute message.
10 11 12 |
# File 'lib/events/message_updated.rb', line 10 def @message end |